@@ -601,7 +601,7 @@ class RedisRoot:
                   f'\n\n\n')
 
     def fast_get_keys_values(self, string):
-        keys = list(self.redis_instance.scan_iter(string))
+        keys = list(self.redis_instance.keys(string))
         values = self.redis_instance.mget(keys)
         results = dict(zip(keys, values))
         return results
@@ -1014,14 +1014,14 @@ class RedisRoot:
         model_name = model.__name__
         updated_datas = []
         if instances is None:
-            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
                 updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                 if updated_data is not None:
                     updated_datas.append(updated_data)
         else:
             ids_to_update = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_update:
-                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
                     updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                     if updated_data is not None:
                         updated_datas.append(updated_data)
@@ -1044,19 +1044,19 @@ class RedisRoot:
         model = self._django_model_to_redis_model(django_model)
         model_name = model.__name__
         if instances is None:
-            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
                 self._delete_by_key(key)
         else:
             ids_to_delete = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_delete:
-                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
                     self._delete_by_key(key)
 
     # def get_id_from_django_id(self, django_model, django_id):
     #     model_name = django_model.__name__
     #     check_types(django_id, int)
     #     result = False
-    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*:django_id'):
+    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*:django_id'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = int(self.redis_instance.get(key))
     #         if value == django_id:
@@ -1067,7 +1067,7 @@ class RedisRoot:
     #     model_name = django_model.__name__
     #     check_types(instance_id, int)
     #     result = False
-    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}:edited'):
+    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}:edited'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = bool(int(self.redis_instance.get(key)))
     #         result = value
@@ -1155,20 +1155,10 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
-                    if isinstance(field, RedisForeignKey):
-                        if field.value is not None:
-                            id = get_ids_from_untyped_data(field.value)[0]
-                            deserialized_value = redis_root.deserialize_value(id, name, field_name)
-                    elif isinstance(field, RedisManyToMany):
-                        if field.value is not None:
-                            ids = get_ids_from_untyped_data(field.value)
-                            deserialized_value = redis_root.deserialize_value(ids, name, field_name)
-                    else:
-                        deserialized_value = redis_root.deserialize_value(field.value, name, field_name)
-                    deserialized_fields[field_name] = deserialized_value
                     cleaned_value = field.clean()
-
                     cleaned_fields[field_name] = cleaned_value
+                    deserialized_value = redis_root.deserialize_value(cleaned_value, name, field_name)
+                    deserialized_fields[field_name] = deserialized_value
                 except BaseException as ex:
                     raise Exception(f'{ex} ({name} -> {field_name})')
         return instance_key, cleaned_fields, deserialized_fields
